<?php

// Catalan language include
// For version 2.0 PHP iCalendar
//
// Translation by Oriol Ferrer Mesia; (tm05788@salleurl.edu)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day']				= "Dia";
$lang['l_week']				= "Setmana";
$lang['l_month']			= "Mes";
$lang['l_year']				= "Any";
$lang['l_calendar']			= "Calendari";
$lang['l_next_day']			= "Dia seg&uuml;ent";
$lang['l_next_month']		= "Mes seg&uuml;ent";
$lang['l_next_week']		= "Setmana seg&uuml;ent";
$lang['l_next_year']		= "Any seg&uuml;ent";
$lang['l_last_day']			= "Dia anterior";
$lang['l_last_month']		= "Mes anterior";
$lang['l_last_week']		= "Setmana anterior";
$lang['l_last_year']		= "Any anterior";
$lang['l_subscribe']		= "Subscriure";
$lang['l_download']			= "Descarregar";
$lang['l_powered_by'] 		= "Gr&agrave;cies a";
$lang['l_event']			= 'Event';
$lang['l_event_start']		= 'Inici';
$lang['l_event_end']		= 'Fi';
$lang['l_this_months']		= 'Events d\'aquest mes';
$lang['l_date']				= 'Data';
$lang['l_summary']			= 'Descripci&oacute;';
$lang['l_all_day']			= 'Event diario';
$lang['l_notes']			= 'Notes';
$lang['l_this_years']		= 'Events d\'aquest any';
$lang['l_today']			= 'Avui';
$lang['l_this_week']		= 'Aquesta setmana';
$lang['l_this_month']		= 'Aquesta mes';
$lang['l_jump']				= 'Anar a';
$lang['l_tomorrows']		= 'Events de dem&agrave;';
$lang['l_goday']			= 'Anar a Avui';
$lang['l_goweek']			= 'Anar a aquesta Setmana';
$lang['l_gomonth']			= 'Anar a aquest Mes';
$lang['l_goyear']			= 'Anar a aquest Any';
$lang['l_search']			= 'Buscar'; // the verb
$lang['l_results']			= 'Resultats de la cerca';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query']			= 'Consulta: '; // will be followed by the search query
$lang['l_no_results']		= 'No s\'ha trobat cap event';
$lang['l_goprint']			= 'Format d\'impressi&oacute;';
$lang['l_time']				= 'Hora';
$lang['l_summary']			= 'Resum';
$lang['l_description']		= 'Descripci&oacute;';
$lang['l_this_site_is']		= 'Aquesta p&agrave;gina &eacute;s';
$lang['l_no_events_day']	= 'No hi ha events per a avui.';
$lang['l_no_events_week']	= 'No hi ha events per a aquesta setmana.';
$lang['l_no_events_month']	= 'No hi ha events per a aquest mes.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date']	= '%e de %b';  // Lists just the day
$lang['l_rss_month_date']	= '%e de %b';  // Lists just the day
$lang['l_rss_language']		= 'en-us';
$lang['l_search_took']		= 'La cerca ha trigat %s segons';
$lang['l_recurring_event']	= 'Event peri&ograve;dic';
$lang['l_exception']		= 'Excepci&oacute;';
$lang['l_no_query']			= 'Sense consulta';
$lang['l_preferences']		= 'Prefer&egrave;ncies';
$lang['l_printer']			= 'Impressora';
$lang['l_select_lang']		= 'Esculli el seu idioma per defecte:';
$lang['l_select_cal']		= 'Esculli el seu calendari per defecte:';
$lang['l_select_view']		= 'Esculli la seva vista per defecte:';
$lang['l_select_time']		= 'Esculli la seva hora d\'inici per defecte:';
$lang['l_select_day']		= 'Esculli el seu dia inicial de la setmana:';
$lang['l_select_style']		= 'Esculli el seu estil per defecte:';
$lang['l_set_prefs']		= 'Guardar prefer&egrave;ncies';
$lang['l_completed_date']	= 'Finalitzat a';
$lang['l_completed']		= 'Finalitzat';
$lang['l_created']			= 'Creat:';
$lang['l_due']				= 'Fins:';
$lang['l_priority']			= 'Prioritat:';
$lang['l_priority_high']	= 'Alta';
$lang['l_priority_low']		= 'Baixa';
$lang['l_priority_medium']	= 'Mitjana';
$lang['l_priority_none']	= 'Cap';
$lang['l_status']			= 'Estat';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'Pendent';
$lang['l_unfinished']		= 'Sense acabar';
$lang['l_prefs_set'] 		= 'Les teves prefer&egrave;ncies s\'han guardat.';
$lang['l_prefs_unset'] 		= 'Les prefer&egrave;ncies s\'han esborat. Els canvis ser&agrave;n visibles quan es recarregui la p&agrave;gina';
$lang['l_unset_prefs'] 		= 'Esborra les prefer&egrave;ncies:';
$lang['l_organizer']		= 'Organitzador';
$lang['l_attendee']			= 'Persones presents';
$lang['l_location']			= 'Lloc';
$lang['l_admin_header']		= 'Administraci&oacute; PHP iCalendar';
$lang['l_username']			= 'Nom d\'usuari';
$lang['l_password']			= 'contrasenya';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Nom d\'usuari o contrasenya incorrectes.';
$lang['l_addupdate_cal']	= 'Afegeix o actualitza un Calendari';
$lang['l_addupdate_desc']	= 'Afegeix un Calendari enviant un fitxer. Actualitza un Calendari enviant un fitxer amb el mateix nom.';
$lang['l_delete_cal']		= 'Esborra un Calendari';
$lang['l_logout']			= 'Desconnexi&oacute;';
$lang['l_cal_file']			= 'Fitxer de Calendari';
$lang['l_php_error']		= 'Error de PHP ';
$lang['l_upload_error_gen']	= 'Hi ha hagut un error en el proc&eacute;s d\'enviament.';
$upload_error_lang[0]	= 'Hi ha hagut un error en el proc&eacute;s d\'enviament.';
$upload_error_lang[1]	= 'El fitxer enviat &eacute;s massa gran.';
$upload_error_lang[2]	= 'El fitxer enviat &eacute;s massa gran.';
$upload_error_lang[3]	= 'El fitxer ha estat enviat nom&eacute;s parcialment.';
$upload_error_lang[4]	= 'Cal sel&middot;leccionar un fitxer a enviar.';
$lang['l_upload_error_type'] = 'Nomes es poden enviar fitxers del tipus .ics.';
$lang['l_copy_error']		= 'Error durant la c&ograve;pia del fitxer.';
$lang['l_delete_error']		= 'Error al esborrar el fitxer.';
$lang['l_delete_success']	= 'ha estat eliminat.';
$lang['l_action_success']	= 'L\'acci&oacute; ha acabat satisfact&ograve;riament.';
$lang['l_submit']			= 'Envia';
$lang['l_delete']			= 'Esborra';
$lang['l_all_cal_comb']		= 'Tots els calendaris alhora';

// New for 2.0
$lang['l_legend']			= 'Legend';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] = 'Endarrera';
$lang['l_next'] = 'Seg&uuml;ent';
$lang['l_prev'] = 'Anterior';
$lang['l_day_view'] = 'Vista Di&agrave;ria';
$lang['l_week_view'] = 'Vista Setmanal';
$lang['l_month_view'] = 'Vista Mensual';
$lang['l_year_view'] = 'Vista Anual';

// ---------------------------------

// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('any','anys');		// for these, put singular
$format_recur_lang['monthly']		= array('mes','mesos');		// and plural forms
$format_recur_lang['weekly']		= array('setmana','setmanes');		// these will be %freq%
$format_recur_lang['daily']			= array('dia','dies');			// in the replacement below
$format_recur_lang['hourly']		= array('hora','hores');
$format_recur_lang['minutely']		= array('minut','minuts');
$format_recur_lang['secondly']		= array('segon','segons');

$format_recur_lang['start']			= 'Cada %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'fins al %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int% vegades';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Durant els mesos: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Durant els dies: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Durant els dies de la setmana: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Diumenge','Dilluns','Dimarts','Dimecres','Dijous','Divendres','Dissabte');
$daysofweekshort_lang		= array ('Dium','Dill','Dima','Dime','Dij','Div','Dis');
$daysofweekreallyshort_lang	= array ('D','L','M','X','J','V','S');
$monthsofyear_lang			= array ('Gener','Febrer','Mar&ccedil;','Abril','Maig','Juny','Juliol','Agost','Setembre','Octubre','Novembre','Desembre');
$monthsofyearshort_lang		= array ('Gen','Feb','Mar','Abr','Mai','Jun','Jul','Ago','Sep','Oct','Nov','Des');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'G:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %e de %B';
$dateFormat_week = '%e de %B';
$dateFormat_week_list = '%a, %e de %b';
$dateFormat_week_jump = '%e de %b';
$dateFormat_month = '%B de %Y';
$dateFormat_month_list = '%A, %e de %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Error!';
$lang['l_error_window'] 		= 'Hi ha hagut error!';
$lang['l_error_calendar'] 		= 'L\'error s\'ha produ&iuml;t mentre es processava el calendari "%s".';
$lang['l_error_path'] 			= 'Incapa&ccedil; d\'obrir: "%s"';
$lang['l_error_back'] 			= 'Per favor, utilitzi el bot&oacute; "endarrera" per a tornar.';
$lang['l_error_remotecal'] 		= 'Aquest servidor bloqueja calendaris remots que no han estat acceptats.';
$lang['l_error_restrictedcal'] 	= 'Ha intentat arribar a un calendari que t&eacute; l\'acc&eacute;s restringit.';
$lang['l_error_invalidcal'] 	= 'Fitxer de calendari inv&agrave;lid. Per favor, provi un altre calendari.';


?>
